@@ -1,7 +1,7 @@
 package App::SetScreensaverTimeout;
 
-our $DATE = '2015-01-08'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2015-06-05'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -24,7 +24,9 @@ sub _get_or_set {
     my $detres = detect_desktop();
 
     local $Proc::Find::CACHE = 1;
-    if (proc_exists(name=>"gnome-screensaver")) {
+
+    if (proc_exists(name=>"gnome-screensaver") ||
+            $detres->{desktop} =~ /^gnome(-classic)?$/) {
         if ($which eq 'set') {
             my $secs = $mins*60;
             system "gsettings", "set", "org.gnome.desktop.session",
@@ -194,19 +196,31 @@ App::SetScreensaverTimeout - Set screensaver timeout
 
 =head1 VERSION
 
-This document describes version 0.08 of App::SetScreensaverTimeout (from Perl distribution App-SetScreensaverTimeout), released on 2015-01-08.
+This document describes version 0.09 of App::SetScreensaverTimeout (from Perl distribution App-SetScreensaverTimeout), released on 2015-06-05.
+
+=head1 KNOWN BUGS
+
+=over
+
+=item * Sometimes fail to lock on KDE
+
+KDE is supposed to pick up on the changes in
+`~/.kde/share/config/kscreensaverrc` immediately, and this is confirmed by
+running the dialog `kcmshell4 screensaver`. However, sometimes the change does
+not take effect and the screensaver won't trigger even after the timeout has
+long passed.
+
+=back
 
 =head1 FUNCTIONS
 
 
 =head2 get_screensaver_timeout() -> [status, msg, result, meta]
 
-{en_US Get screensaver timeout (in minutes)}.
+Get screensaver timeout (in minutes).
 
-{en_US 
 Provide a common way to get screensaver timeout setting. Support several screen
 savers (see C<set_screensaver_timeout>).
-}
 
 No arguments.
 
@@ -219,14 +233,13 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-Return value: {en_US Timeout value, in minutes} (float)
+Return value: Timeout value, in minutes (float)
 
 
 =head2 set_screensaver_timeout(%args) -> [status, msg, result, meta]
 
-{en_US Set screensaver timeout}.
+Set screensaver timeout.
 
-{en_US 
 Provide a common way to quickly set screensaver timeout. Will detect the running
 screensaver/desktop environment and set accordingly. Supports xscreensaver,
 gnome-screensaver, and KDE screen locker. Support for other screensavers will be
@@ -257,7 +270,6 @@ C<~/.kde/share/config/kscreensaverrc>:
   Timeout=300
 
 modifies the line, save the file.
-}
 
 =back
 
@@ -267,7 +279,7 @@ Arguments ('*' denotes required arguments):
 
 =item * B<timeout> => I<str>
 
-{en_US Value, default in minutes}.
+Value, default in minutes.
 
 =back
 
@@ -282,20 +294,6 @@ that contains extra information.
 
 Return value:  (any)
 
-=head1 KNOWN BUGS
-
-=over
-
-=item * Sometimes fail to lock on KDE
-
-KDE is supposed to pick up on the changes in
-`~/.kde/share/config/kscreensaverrc` immediately, and this is confirmed by
-running the dialog `kcmshell4 screensaver`. However, sometimes the change does
-not take effect and the screensaver won't trigger even after the timeout has
-long passed.
-
-=back
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-SetScreensaverTimeout>.
